# Changelog

## [0.3.0](https://github.com/CQCL/tket2/compare/tket2-eccs-v0.2.0...tket2-eccs-v0.3.0) (2024-12-16)


### ⚠ BREAKING CHANGES

* Updated `hugr` rust dependency to `0.14.0`. The bundled ECC sets are now compatible with `hugr 0.10`.


### Miscellaneous Chores

* Update to next version of hugr ([#720](https://github.com/CQCL/tket2/issues/720)) ([4a3a5a5](https://github.com/CQCL/tket2/commit/4a3a5a5e38252d4ee709e7e97bb5a1e90bd9fff4))

## [0.2.0](https://github.com/CQCL/tket2/compare/tket2-eccs-v0.1.0...tket2-eccs-v0.2.0) (2024-10-10)


### ⚠ BREAKING CHANGES

* Recompiled eccs with `hugr 0.13.0`

## 0.1.0 (2024-08-01)


### Features

* Move the compiled eccs to a separate package ([#517](https://github.com/CQCL/tket2/issues/517)) ([7247cc6](https://github.com/CQCL/tket2/commit/7247cc65f4c4e679fd5b680d1e53e630f06d94a1))

## Changelog
